use leptos::*;
use crate::app::models::Post;

#[server]
pub async fn get_posts(
    folder: String
) -> Result<Vec<Post>, ServerFnError> {
    let posts = Post::get_all(&folder)
        .map_err(|e| ServerFnError::ServerError(e.to_string()))?;

    Ok(posts)
}

#[component]
pub fn PostList(
    folder: String
) -> impl IntoView {
    let posts = create_resource(|| (), |_| get_posts("posts".to_string()));

    let posts_view = move || {
        posts.and_then(|posts| {
            posts.iter()
                .map(|post| view! {
                                <li>
                                    {post.metadata.title.clone()}
                                    <div>
                                        {post.content.clone()}
                                    </div>
                                </li>
                            })
                .collect_view()
        })
    };

    view! {
        <main class="m-0 p-0 bg-surface dark:bg-dark_surface text-on_surface dark:text-dark_on_surface">
            <h1>"My Great Blog"</h1>

            <Suspense fallback=move || view! { <p>"Loading posts..."</p> }>
                <ul>{posts_view}</ul>
            </Suspense>
        </main>
    }
}